@@ -64,7 +64,7 @@ package Catmandu::FedoraCommons;
 
 use Catmandu::FedoraCommons::Response;
 
-our $VERSION = '0.273';
+our $VERSION = '0.274';
 use URI::Escape;
 use HTTP::Request::Common qw(GET POST DELETE PUT HEAD);
 use LWP::UserAgent;
@@ -72,7 +72,6 @@ use MIME::Base64;
 use strict;
 use Carp;
 use Data::Validate::URI qw(is_uri);
-use Data::Dumper;
 
 =head2 new($base_url,$username,$password)
 
@@ -190,6 +189,7 @@ sub _PUT {
             open(my $fh,'<',$file) or Carp::croak "can't open $file : $!";
             local($/) = undef;
             $req->content(scalar(<$fh>));
+            $req->header( 'Content-Length' => -s $file );
             close($fh);
         }
         else {
